# How to not die in your marauder

---

## Synopsis

This guide will give you the basics of how to not to die and be effective, it is a baseline not a goal, you pilot your ship and you are responsible for it, you should always try to improve. **IF IN DOUBT ASK THE FC**, we dont bite to much, but we do expect you to apply what you have learned. Whether or not you have flown High Sec incursions before, we will work with you from the ground up on a few ways to maximize your DPS and time in bastion as that is the goal of flying a marauder.

You may feel scared to bastion initially, however read this guide and it will explain dangerous situations, and also tell you the safest ways to bastion and maximize your DPS output.

The biggest part of this is to ask your FC for help if you are not sure about something and don't feel safe, they will clarify and help you feel safer in those situations so you can click the sexy button :D

![Bastion Module](bastionmodule.png)← Sexy Button <3

## How to fly your marauder safely and effectively

### Step 1: Space your guns for contests

This will spread heat damage from Gun → Utility → Gun → etc… and in a contest you will be able to heat longer. You want your highslots to look something like this:

![Gun Layout for Optimal Heat](gunlayout.png)

### Step 2: Use drugs

There are many types of different drugs, when possible we ask you to use the bare minimum to be effective. Use what works well with your chosen ship.

- Pyrolancea gives turret DPS for all weapons (Always run DB3 as a minimum)

![Pyrolancea Drug](pyrolancea.png)

---

- Halcyon drugs or the "login" drugs give multiple bonuses but as a marauder you should prioritise DPS when you can. But best of all, they are **free** and will expire unless used.

![Halcyon Login Drugs](halcyon.png)

---

- Drop gives tracking bonuses for turrets which will give you "applied DPS" but can come with drawbacks using the stonger versions. The stronger versions should only really be used with **ARMOR** tanked ships. **CHECK BEFORE USE!**

![Drop Drug](drop.png)

---

- Synth Frentix gives optimal range bonuses for turrets which will give you "applied DPS" but can come with drawbacks using the stonger versions, therefore you should **ONLY USE THE SYNTH** version of this drug.

![Frentix Drug](frentix.png)

---

- Synth Blue Pill gives increased shield boost amount thus improving your shield tank, this is great for any shield tanked ships as it has no drawbacks. We do not recommend stronger versions due to drawbacks.

![BluePill Drug](bluepill.png)

---

- Synth Mindflood gives cap recharge, great if you have poor capacitor skills and keeps you firing those guns.

![Mindflood Drug](mindflood.png)

---

### Step 3: How to bastion (when to and how to tank)

When you activate bastion on your marauder you are no longer able to receive remote reps from the fleet. This means that if you pull aggro while in bastion you have to be able to tank long enough to exit bastion and receive reps. However, this directly contradicts our ethos of "we want you to be in bastion as much as possible" so understanding when to bastion is key. One of the main things to listen for in fleet is the word **"switch"** as detailed below.

Aggro will **switch** every minute or 60 seconds. Once aggro has switched/established and it's not split or on you, you are safe to bastion for 1 cycle. If for any reason you are not sure when a switch has happened or you missed it, do not bastion until you know when the next switch has happened, if you are not sure ASK! When flying a Paladin, listen to the FC and pay attention as low Kronos numbers in fleet may lead to you pulling aggro so pay attention to your cycles. For shield tanked ships its important to broadcast cap if you need it, if your tank turns off you will explode very quickly, you cannot recieve cap during bastion but broadcasting for it will ensure everyone knows you will need it when you come out of bastion.

There will always be odd scenarios or mistakes in fleet, the FC will be doing their best to ensure this is kept to a minimum but you can pay attention and ensure your own safety by being aware of whats going on. If the FCs booster is not correctly positioned to pull aggro then it is advised to not be in bastion when new waves spawn incase you get the initial aggro.

If you pull aggro in bastion:

- The first thing you should do is broadcast your tank type. We do not use "troll" broadcasts as we have dual logi.

- Secondly give the FC a voice over of how long until your bastion cycle is going to end. Counting down the final 10 seconds or so will aid the logi in applying reps the moment you come out of bastion if its a close call.

- Thirdly overheat any active tank modules your ship might be fitted with

Giving this information is key to the FC as they cannot make decisions to aid in your survival without it. **DO NoT DIE IN SILENCE!**.

There are other small things you can do to make life easier for everyone, such as broadcasting again when you come out of bastion, not broadcasting for troll aggro directly after a switch etc. Using your battle reps on other marauders when logi are not on grid/in range is a must, it could be you that needs them so use them for others when its neccessary and others will return the favor when you need it.

### Step 4: TCRC entry & NRF entry

Entrances to TCRCs are usually very structured, but there are occasions things dont go to plan. It may seem obvious, but if you are in doubt, dont bastion and ask if its safe to do so. Our normal running procedure once aggro is established is you bastion for one cycle on the beacon and shoot:

- Deltole
- Outuni
- UNTAGGED Ostingele

#### NEVER SHOOT TAG X UNLESS GIVEN SPECIFIC INSTRUCTION FROM FC

Once the above NPCs are dead you will MJD to the tower and proceed to do your second bastion cycle, the fleet will always have a "lightning rod" pilot who will effectively be pre-determining where the aggro will go, but again, pay attention to when switches happen and bastion timely to ensure your own safety.

Entrances to NRFs are only dangerous should you not pay attention and micro jump drive blindly into your anchor spot. So when you enter an NRF after checking for phenomena, assess the grid, if the final wave is about to spawn, burn into the site, if you have any doubt as to your safety, **use your micro warp drive to burn into site the rather than micro jump drive**.

### Step 5: Roles & whats expected of them

There are several roles in TLA fleets each with specific jobs or tasks, they are listed below with a brief summary. Roles are always required, so if someone is not listed for a role in the fleet MOTD, x-up for the role, your FC will appreciate not having to ask. Newer pilots are expected to help out with these roles while working towards their T badge DPS number.

- DDD

  The Vindicator(s) in fleet, responsible for killing frigates in all sites, and primarily Niarjas in TCRC's. Specific guidance can be found [here](guide/ddd).

- Meatshield

  Usually occupied by a command ship: Damnation, Claymore, Eos etc. Provides consistent aggro management due to its placement and provides secondary boosts and links to the fleet.

- LR (Lightning rod)

  Is usually made up of two Kronos from different pilots (in case of DC) and its job is to obtain aggro during TCRCs by jumping directly to the tower & shooting it at the entry to the site. Care must be taken not to be slow as mistimed bastions can lead to switches happening during a long cycle of your bastion, if in doubt, ask. The idea with LR is to "tag team" the aggro by bouncing it between the two listed pilots.

- MTAC

  Is held by either Vargur or Paladin equipped with a Tractor Beam, this pilot will jump directly to the MTAC factory in TCRC's and prevent the tower from repping by placing the MTAC into the Shield Transfer Array by means of a cargo container, this process is repeated until site completion. MTAC pilots always have permission to exit a TCRC site once the tower dies without the need for FC approval.

- PS (Pally squad)

  Is held by a dual boxer Paladin or Vargur and shoots 2 to 5 Yulais during TCRCs, this is done by jumping to the right of the TCRC tower at the start of the site and shooting the two Yulais above the tower and the three to the right of it. This pilot does not need to bastion on the beacon like the rest of the fleet.

- Scout

  The unsung hero of the fleet, provides information on other fleets in system by tagging sites, DSCANs of fleet compositions & also provides pre-loads of TCRC's.
